@@ -1,6 +1,9 @@
 # -*- coding: utf-8 -*-
 
-from nose.tools.trivial import assert_equals, assert_true, assert_false, assert_is, assert_is_instance
+from nose.tools.trivial import (
+    assert_equals, assert_true, assert_false,
+    assert_is_instance
+)
 
 from valhalla import Schema
 
